// AUTOMATICALLY GENERATED BY wordarrays ANALYZER.
#include "StdAfx.h"
_TCHAR *word21[]={0,
_T("acetylcholinesterases"),_T("adrenocorticosteroids"),_T("adrenocorticotrophins"),_T("anthropomorphizations"),_T("antiauthoritarianisms"),_T("antiferromagnetically"),_T("buckminsterfullerenes"),_T("clinicopathologically"),_T("compartmentalizations"),_T("constitutionalization"),
_T("contemporaneousnesses"),_T("countercountermeasure"),_T("counterdemonstrations"),_T("counterinterpretation"),_T("dendrochronologically"),_T("disadvantageousnesses"),_T("disestablishmentarian"),_T("electrocardiographies"),_T("electroencephalograms"),_T("electroencephalograph"),
_T("electromyographically"),_T("electroretinographies"),_T("establishmentarianism"),_T("extraterritorialities"),_T("hypercholesterolemias"),_T("hypersusceptibilities"),_T("immunocytochemistries"),_T("immunoelectrophoreses"),_T("immunoelectrophoresis"),_T("immunoelectrophoretic"),
_T("incomprehensibilities"),_T("indistinguishableness"),_T("institutionalizations"),_T("interchangeablenesses"),_T("interconvertibilities"),_T("internationalizations"),_T("intersubstitutability"),_T("meningoencephalitides"),_T("microminiaturizations"),_T("multidimensionalities"),
_T("neuroendocrinological"),_T("neuroendocrinologists"),_T("nondenominationalisms"),_T("otorhinolaryngologies"),_T("otorhinolaryngologist"),_T("overcommercialization"),_T("overintellectualizing"),_T("phosphoglyceraldehyde"),_T("photolithographically"),_T("photophosphorylations"),
_T("pseudocholinesterases"),_T("pseudosophistications"),_T("psychopharmacological"),_T("psychopharmacologists"),_T("psychophysiologically"),_T("psychotherapeutically"),_T("stereomicroscopically"),_T("straightforwardnesses"),_T("tetrahydrocannabinols"),_T("unconstitutionalities"),
_T("undemonstrativenesses"),_T("unexceptionablenesses"),
0};
