// AUTOMATICALLY GENERATED BY wordarrays ANALYZER.
#include "StdAfx.h"
_TCHAR *word19[]={0,
_T("accommodativenesses"),_T("adrenocorticotropic"),_T("adrenocorticotropin"),_T("adventuresomenesses"),_T("agammaglobulinemias"),_T("angiocardiographies"),_T("anthropocentrically"),_T("anthropomorphically"),_T("antiadministrations"),_T("anticholinesterases"),
_T("anticonservationist"),_T("antidesertification"),_T("antiferromagnetisms"),_T("antifluoridationist"),_T("antirevolutionaries"),_T("antivivisectionists"),_T("authoritativenesses"),_T("bacteriochlorophyll"),_T("bourgeoisifications"),_T("characterologically"),
_T("chlorofluorocarbons"),_T("chlorofluoromethane"),_T("chromatographically"),_T("chromolithographers"),_T("chromolithographies"),_T("chromolithographing"),_T("cinematographically"),_T("circumstantialities"),_T("clinicopathological"),_T("communicativenesses"),
_T("companionablenesses"),_T("compassionatenesses"),_T("complementarinesses"),_T("comprehensibilities"),_T("comprehensivenesses"),_T("conceptualistically"),_T("conscientiousnesses"),_T("consequentialnesses"),_T("constitutionalities"),_T("constitutionalizing"),
_T("contemplativenesses"),_T("contemporaneousness"),_T("contradictorinesses"),_T("contradistinctively"),_T("contradistinguished"),_T("contradistinguishes"),_T("conventionalization"),_T("counteradvertisings"),_T("counterconditioning"),_T("counterconspiracies"),
_T("counterculturalisms"),_T("counterdemonstrated"),_T("counterdemonstrates"),_T("counterdemonstrator"),_T("counterinflationary"),_T("counterinstitutions"),_T("counterinsurgencies"),_T("counterintelligence"),_T("countermobilization"),_T("counterprogrammings"),
_T("counterreformations"),_T("counterretaliations"),_T("countersurveillance"),_T("countertransference"),_T("crosslinguistically"),_T("cytodifferentiation"),_T("cytopathogenicities"),_T("dehydrochlorinating"),_T("dehydrochlorination"),_T("deindustrialization"),
_T("deinstitutionalized"),_T("deinstitutionalizes"),_T("demonstrativenesses"),_T("dendrochronological"),_T("dendrochronologists"),_T("deoxyribonucleotide"),_T("departmentalization"),_T("diastereoisomerisms"),_T("diethylcarbamazines"),_T("diethylstilbestrols"),
_T("differentiabilities"),_T("dimethylnitrosamine"),_T("dimethyltryptamines"),_T("directionlessnesses"),_T("disadvantagednesses"),_T("disadvantageousness"),_T("disenfranchisements"),_T("disinterestednesses"),_T("dispassionatenesses"),_T("disproportionations"),
_T("disrespectabilities"),_T("disrespectfulnesses"),_T("electrocardiographs"),_T("electrocardiography"),_T("electrocorticograms"),_T("electrodesiccations"),_T("electrodynamometers"),_T("electroluminescence"),_T("electromagnetically"),_T("electromechanically"),
_T("electrometallurgies"),_T("electronegativities"),_T("electrophoretically"),_T("electrophoretograms"),_T("electrophotographic"),_T("electrophysiologies"),_T("electrophysiologist"),_T("electroretinographs"),_T("electroretinography"),_T("encephalomyelitides"),
_T("entrepreneurialisms"),_T("establishmentarians"),_T("ethnomethodologists"),_T("evapotranspirations"),_T("exhibitionistically"),_T("expressionistically"),_T("extralinguistically"),_T("extraordinarinesses"),_T("extraterritoriality"),_T("gastroenterological"),
_T("gastroenterologists"),_T("gedankenexperiments"),_T("gentlemanlikenesses"),_T("glottochronological"),_T("hemidemisemiquavers"),_T("heterogeneousnesses"),_T("histopathologically"),_T("historiographically"),_T("homotransplantation"),_T("hydrochlorothiazide"),
_T("hydrometeorological"),_T("hydrometeorologists"),_T("hyperconcentrations"),_T("hyperemotionalities"),_T("hyperexcitabilities"),_T("hyperirritabilities"),_T("hyperparathyroidism"),_T("hypersensitizations"),_T("hypersusceptibility"),_T("hypoparathyroidisms"),
_T("immunocytochemistry"),_T("immunofluorescences"),_T("immunohematological"),_T("immunohematologists"),_T("immunohistochemical"),_T("immunoprecipitating"),_T("immunoprecipitation"),_T("impressionabilities"),_T("impressionistically"),_T("inappropriatenesses"),
_T("incommunicabilities"),_T("incomprehensibility"),_T("inconceivablenesses"),_T("inconsideratenesses"),_T("inconspicuousnesses"),_T("indefatigablenesses"),_T("indescribablenesses"),_T("indestructibilities"),_T("indeterminatenesses"),_T("indispensablenesses"),
_T("individualistically"),_T("inefficaciousnesses"),_T("inexhaustiblenesses"),_T("inexpressiblenesses"),_T("instantaneousnesses"),_T("intellectualization"),_T("interavailabilities"),_T("interchangeableness"),_T("intercommunications"),_T("interconvertibility"),
_T("interdenominational"),_T("interdepartmentally"),_T("interferometrically"),_T("interjurisdictional"),_T("interorganizational"),_T("interstratification"),_T("intersubjectivities"),_T("introspectivenesses"),_T("irreconcilabilities"),_T("irrecoverablenesses"),
_T("irreplaceablenesses"),_T("irreproachabilities"),_T("irreproducibilities"),_T("irresponsiblenesses"),_T("knowledgeablenesses"),_T("lipopolysaccharides"),_T("magnetohydrodynamic"),_T("meningoencephalitic"),_T("meningoencephalitis"),_T("methylcholanthrenes"),
_T("methylprednisolones"),_T("microdensitometries"),_T("microelectronically"),_T("microencapsulations"),_T("micrometeorological"),_T("micrometeorologists"),_T("micropaleontologies"),_T("micropaleontologist"),_T("miscellaneousnesses"),_T("mischaracterization"),
_T("mucopolysaccharides"),_T("multidimensionality"),_T("multitudinousnesses"),_T("neurofibromatosises"),_T("neuropharmacologies"),_T("neuropharmacologist"),_T("nonenforceabilities"),_T("noninterventionists"),_T("nonproductivenesses"),_T("nonrelativistically"),
_T("nonrepresentational"),_T("objectionablenesses"),_T("otorhinolaryngology"),_T("overambitiousnesses"),_T("overcapitalizations"),_T("overcentralizations"),_T("overclassifications"),_T("overcommercializing"),_T("overdifferentiation"),_T("overgeneralizations"),
_T("overidentifications"),_T("overindustrializing"),_T("overintellectualize"),_T("overinterpretations"),_T("overproportionately"),_T("overrepresentations"),_T("oversensitivenesses"),_T("oversimplifications"),_T("overspecializations"),_T("ovoviviparousnesses"),
_T("paleoanthropologies"),_T("paleoanthropologist"),_T("paleoclimatologists"),_T("paleogeographically"),_T("paradichlorobenzene"),_T("parasympathomimetic"),_T("parathyroidectomies"),_T("parthenogenetically"),_T("perspicaciousnesses"),_T("pharmacodynamically"),
_T("phenomenalistically"),_T("phenylpropanolamine"),_T("phenylthiocarbamide"),_T("phonocardiographies"),_T("phosphatidylcholine"),_T("phosphoenolpyruvate"),_T("phosphofructokinase"),_T("phosphoglucomutases"),_T("phosphomonoesterase"),_T("photoconductivities"),
_T("photodecompositions"),_T("photodisintegrating"),_T("photodisintegration"),_T("photofluorographies"),_T("photointerpretation"),_T("photoreconnaissance"),_T("photosensitizations"),_T("phytogeographically"),_T("phytohemagglutinins"),_T("polychromatophilias"),
_T("polyesterifications"),_T("polyribonucleotides"),_T("postmillenarianisms"),_T("posttranscriptional"),_T("prefigurativenesses"),_T("preternaturalnesses"),_T("professionalization"),_T("proletarianizations"),_T("pseudosophisticated"),_T("psychopharmacologic"),
_T("psychophysiological"),_T("psychophysiologists"),_T("psychotomimetically"),_T("radioallergosorbent"),_T("radiopharmaceutical"),_T("reconceptualization"),_T("reindustrialization"),_T("reprehensiblenesses"),_T("representationalism"),_T("representationalist"),
_T("reticuloendothelial"),_T("revolutionarinesses"),_T("sanctimoniousnesses"),_T("semiconsciousnesses"),_T("sentimentalizations"),_T("spectrofluorimeters"),_T("spectrofluorometers"),_T("spectrofluorometric"),_T("spectrophotometries"),_T("splendiferousnesses"),
_T("stereophotographies"),_T("stereospecificities"),_T("straightforwardness"),_T("structurelessnesses"),_T("superadministrators"),_T("superconductivities"),_T("superspecialization"),_T("symptomatologically"),_T("tenderheartednesses"),_T("territorializations"),
_T("thermoelectricities"),_T("thermoluminescences"),_T("thermoperiodicities"),_T("transformationalist"),_T("transmogrifications"),_T("transplantabilities"),_T("transubstantiations"),_T("tridimensionalities"),_T("ultracentrifugation"),_T("ultracontemporaries"),
_T("ultrasegregationist"),_T("unapproachabilities"),_T("unceremoniousnesses"),_T("uncompetitivenesses"),_T("unconscionabilities"),_T("unconstitutionality"),_T("uncontrollabilities"),_T("unconventionalities"),_T("undemonstrativeness"),_T("underrepresentation"),
_T("understandabilities"),_T("unexceptionableness"),_T("unfashionablenesses"),_T("unidimensionalities"),_T("unintelligibilities"),_T("unpretentiousnesses"),_T("untranslatabilities"),
0};
