// AUTOMATICALLY GENERATED BY wordarrays ANALYZER.
#include "StdAfx.h"
_TCHAR *word24[]={0,
_T("dichlorodifluoromethanes"),_T("electrocardiographically"),_T("electroencephalographers"),_T("electroencephalographies"),_T("intercomprehensibilities"),_T("microelectrophoretically"),_T("microspectrophotometries"),_T("overintellectualizations"),_T("phosphatidylethanolamine"),
0};
