// AUTOMATICALLY GENERATED BY wordarrays ANALYZER.
#include "StdAfx.h"
_TCHAR *word23[]={0,
_T("carboxymethylcelluloses"),_T("deinstitutionalizations"),_T("dichlorodifluoromethane"),_T("electroencephalographer"),_T("electroencephalographic"),_T("hexamethylenetetramines"),_T("indistinguishablenesses"),_T("intersubstitutabilities"),_T("microspectrophotometers"),_T("microspectrophotometric"),
_T("nonrepresentationalisms"),_T("overintellectualization"),_T("reinstitutionalizations"),
0};
