// AUTOMATICALLY GENERATED BY wordarrays ANALYZER.
#include "StdAfx.h"
_TCHAR *word20[]={0,
_T("acetylcholinesterase"),_T("adrenocorticosteroid"),_T("adrenocorticotrophic"),_T("adrenocorticotrophin"),_T("adrenocorticotropins"),_T("anthropocentricities"),_T("anthropomorphization"),_T("antiauthoritarianism"),_T("anticonservationists"),_T("antifluoridationists"),
_T("bacteriochlorophylls"),_T("buckminsterfullerene"),_T("chemotherapeutically"),_T("chlorofluoromethanes"),_T("coccidioidomycosises"),_T("compartmentalization"),_T("comprehensiblenesses"),_T("contradistinguishing"),_T("conventionalizations"),_T("counterconditionings"),
_T("counterdemonstrating"),_T("counterdemonstration"),_T("counterdemonstrators"),_T("counterintelligences"),_T("countermobilizations"),_T("counterrevolutionary"),_T("countersurveillances"),_T("countertransferences"),_T("crystallographically"),_T("cytodifferentiations"),
_T("dehydrochlorinations"),_T("deindustrializations"),_T("deinstitutionalizing"),_T("deoxyribonucleotides"),_T("departmentalizations"),_T("dimethylnitrosamines"),_T("distinguishabilities"),_T("electrocardiographic"),_T("electroencephalogram"),_T("electroluminescences"),
_T("electrooculographies"),_T("electrophotographies"),_T("electrophysiological"),_T("electrophysiologists"),_T("electroretinographic"),_T("encephalomyocardites"),_T("encephalomyocarditis"),_T("existentialistically"),_T("expressionlessnesses"),_T("extemporaneousnesses"),
_T("forethoughtfulnesses"),_T("glomerulonephritides"),_T("histocompatibilities"),_T("homotransplantations"),_T("hydrochlorothiazides"),_T("hypercholesterolemia"),_T("hypercholesterolemic"),_T("hypercoagulabilities"),_T("hyperconsciousnesses"),_T("hyperparathyroidisms"),
_T("hypersensitivenesses"),_T("immunocytochemically"),_T("immunohistochemistry"),_T("immunoprecipitations"),_T("inappreciativenesses"),_T("incommensurabilities"),_T("incomprehensibleness"),_T("inconsequentialities"),_T("inconsiderablenesses"),_T("indestructiblenesses"),
_T("indiscriminatenesses"),_T("indistinguishability"),_T("institutionalization"),_T("intellectualizations"),_T("interchangeabilities"),_T("interconnectednesses"),_T("internationalization"),_T("interstratifications"),_T("irreconcilablenesses"),_T("irreproachablenesses"),
_T("keratoconjunctivites"),_T("keratoconjunctivitis"),_T("lymphogranulomatoses"),_T("lymphogranulomatosis"),_T("magnetofluiddynamics"),_T("magnetohydrodynamics"),_T("microcrystallinities"),_T("microelectrophoreses"),_T("microelectrophoresis"),_T("microelectrophoretic"),
_T("microminiaturization"),_T("micropaleontological"),_T("micropaleontologists"),_T("microphotometrically"),_T("mischaracterizations"),_T("neuroendocrinologies"),_T("neuroendocrinologist"),_T("neuropharmacological"),_T("neuropharmacologists"),_T("neurophysiologically"),
_T("neuropsychiatrically"),_T("nondenominationalism"),_T("nondestructivenesses"),_T("noninstitutionalized"),_T("overdifferentiations"),_T("overintellectualized"),_T("overintellectualizes"),_T("overprotectivenesses"),_T("paleoanthropological"),_T("paleoanthropologists"),
_T("paradichlorobenzenes"),_T("parathyroidectomized"),_T("phenylpropanolamines"),_T("phenylthiocarbamides"),_T("philoprogenitiveness"),_T("phosphatidylcholines"),_T("phosphoenolpyruvates"),_T("phosphofructokinases"),_T("phosphomonoesterases"),_T("photoautotrophically"),
_T("photodisintegrations"),_T("photointerpretations"),_T("photophosphorylation"),_T("photoreconnaissances"),_T("plethysmographically"),_T("polyphiloprogenitive"),_T("professionalizations"),_T("pseudocholinesterase"),_T("pseudoparenchymatous"),_T("pseudosophistication"),
_T("psychopathologically"),_T("psychopharmacologies"),_T("psychopharmacologist"),_T("radioimmunoassayable"),_T("radiopharmaceuticals"),_T("reconceptualizations"),_T("reindustrializations"),_T("representationalisms"),_T("representationalists"),_T("representativenesses"),
_T("roentgenographically"),_T("semiautobiographical"),_T("spectrofluorometries"),_T("spectroheliographies"),_T("spectrophotometrical"),_T("superspecializations"),_T("syncategorematically"),_T("tetrahydrocannabinol"),_T("transformationalists"),_T("ultracentrifugations"),
_T("ultramicroscopically"),_T("ultrarevolutionaries"),_T("ultrasegregationists"),_T("uncharacteristically"),_T("uncompromisingnesses"),_T("unconscionablenesses"),_T("underrepresentations"),_T("unintelligiblenesses"),_T("unrepresentativeness"),_T("unsatisfactorinesses"),

0};
