// AUTOMATICALLY GENERATED BY wordarrays ANALYZER.
#include "StdAfx.h"
_TCHAR *word22[]={0,
_T("carboxymethylcellulose"),_T("constitutionalizations"),_T("countercountermeasures"),_T("counterinterpretations"),_T("counterrevolutionaries"),_T("deinstitutionalization"),_T("disestablishmentarians"),_T("electroencephalographs"),_T("electroencephalography"),_T("electrophysiologically"),
_T("encephalomyocarditides"),_T("encephalomyocarditises"),_T("establishmentarianisms"),_T("hexamethylenetetramine"),_T("immunohistochemistries"),_T("incomprehensiblenesses"),_T("indistinguishabilities"),_T("intercomprehensibility"),_T("keratoconjunctivitides"),_T("keratoconjunctivitises"),
_T("microspectrophotometer"),_T("microspectrophotometry"),_T("nonrepresentationalism"),_T("otorhinolaryngological"),_T("otorhinolaryngologists"),_T("overcommercializations"),_T("philoprogenitivenesses"),_T("phosphoglyceraldehydes"),_T("reinstitutionalization"),_T("spectrophotometrically"),
_T("unrepresentativenesses"),
0};
