// AUTOMATICALLY GENERATED BY wordarrays ANALYZER.
#include "StdAfx.h"
_TCHAR *word18[]={0,
_T("absentmindednesses"),_T("accumulativenesses"),_T("adenocarcinomatous"),_T("advantageousnesses"),_T("aerothermodynamics"),_T("agammaglobulinemia"),_T("agammaglobulinemic"),_T("anagrammatizations"),_T("angiocardiographic"),_T("anthropocentricity"),
_T("anthropomorphizing"),_T("antiadministration"),_T("anticholinesterase"),_T("anticommercialisms"),_T("anticounterfeiting"),_T("antidiscrimination"),_T("antiferromagnetism"),_T("antischizophrenics"),_T("antivivisectionist"),_T("appreciativenesses"),
_T("apprehensivenesses"),_T("archaeoastronomies"),_T("arteriosclerosises"),_T("astrophotographers"),_T("astrophotographies"),_T("australopithecines"),_T("autobiographically"),_T("bacteriorhodopsins"),_T("biocompatibilities"),_T("biodegradabilities"),
_T("biotransformations"),_T("bloodthirstinesses"),_T("bourgeoisification"),_T("bureaucratizations"),_T("cantankerousnesses"),_T("characteristically"),_T("chemiluminescences"),_T("chlorofluorocarbon"),_T("chlortetracyclines"),_T("cholecystectomized"),
_T("chromolithographed"),_T("chromolithographer"),_T("chromolithographic"),_T("claustrophobically"),_T("coccidioidomycoses"),_T("coccidioidomycosis"),_T("collectivistically"),_T("commensurabilities"),_T("commercializations"),_T("communicablenesses"),
_T("companionabilities"),_T("compartmentalising"),_T("compartmentalizing"),_T("comprehensibleness"),_T("conceptualizations"),_T("congregationalisms"),_T("congregationalists"),_T("consequentialities"),_T("conservativenesses"),_T("constitutionalisms"),
_T("constitutionalists"),_T("constitutionalized"),_T("constitutionalizes"),_T("constructivenesses"),_T("consubstantiations"),_T("contemptiblenesses"),_T("contemptuousnesses"),_T("contradistinctions"),_T("conversationalists"),_T("counteraccusations"),
_T("counteradaptations"),_T("counteradvertising"),_T("counteraggressions"),_T("countercommercials"),_T("counterconventions"),_T("counterculturalism"),_T("counterdemonstrate"),_T("counterdeployments"),_T("countereducational"),_T("countergovernments"),
_T("counterinfluencing"),_T("counterinstitution"),_T("counterintuitively"),_T("counterpetitioning"),_T("counterprogramming"),_T("counterpropagandas"),_T("counterquestioning"),_T("counterreformation"),_T("counterretaliation"),_T("counterrevolutions"),
_T("counterstrategists"),_T("countersuggestions"),_T("creditworthinesses"),_T("curmudgeonlinesses"),_T("deconstructionists"),_T("decriminalizations"),_T("dedifferentiations"),_T("dehydrochlorinases"),_T("dehydrochlorinated"),_T("dehydrochlorinates"),
_T("deinstitutionalize"),_T("deliberativenesses"),_T("dematerializations"),_T("demythologizations"),_T("denationalizations"),_T("dendrochronologies"),_T("dendrochronologist"),_T("denominationalisms"),_T("deoxyribonucleases"),_T("depersonalizations"),
_T("dephosphorylations"),_T("determinablenesses"),_T("dextroamphetamines"),_T("diastereoisomerism"),_T("diethylcarbamazine"),_T("diethylstilbestrol"),_T("dihydroergotamines"),_T("dimethylhydrazines"),_T("dimethyltryptamine"),_T("diphenylhydantoins"),
_T("disagreeablenesses"),_T("disconnectednesses"),_T("disconsolatenesses"),_T("discontentednesses"),_T("discourteousnesses"),_T("discriminabilities"),_T("disenfranchisement"),_T("dishonorablenesses"),_T("disingenuousnesses"),_T("disintermediations"),
_T("disproportionately"),_T("disproportionating"),_T("disproportionation"),_T("disputatiousnesses"),_T("disreputablenesses"),_T("distinguishability"),_T("echocardiographers"),_T("echocardiographies"),_T("electrocardiograms"),_T("electrocardiograph"),
_T("electrochemistries"),_T("electrocorticogram"),_T("electrodepositions"),_T("electrodesiccation"),_T("electrodynamometer"),_T("electroluminescent"),_T("electromyographies"),_T("electrooculography"),_T("electrophilicities"),_T("electrophoretogram"),
_T("electrophotography"),_T("electrophysiologic"),_T("electroretinograms"),_T("electroretinograph"),_T("entrepreneurialism"),_T("epithelializations"),_T("establishmentarian"),_T("ethnomethodologies"),_T("ethnomethodologist"),_T("ethnomusicological"),
_T("ethnomusicologists"),_T("evapotranspiration"),_T("exceptionabilities"),_T("expressionlessness"),_T("extemporaneousness"),_T("exterritorialities"),_T("faintheartednesses"),_T("feeblemindednesses"),_T("ferroelectricities"),_T("forethoughtfulness"),
_T("fractionalizations"),_T("gastroenterologies"),_T("gastroenterologist"),_T("gedankenexperiment"),_T("generalizabilities"),_T("geochronologically"),_T("glomerulonephritis"),_T("glottochronologies"),_T("glycosaminoglycans"),_T("granulocytopoieses"),
_T("granulocytopoiesis"),_T("greatheartednesses"),_T("handcraftsmanships"),_T("heavyheartednesses"),_T("hemidemisemiquaver"),_T("hemoglobinopathies"),_T("histocompatibility"),_T("histophysiological"),_T("homoscedasticities"),_T("hydroelectricities"),
_T("hydrometallurgical"),_T("hydrometallurgists"),_T("hydrometeorologies"),_T("hydrometeorologist"),_T("hydroxytryptamines"),_T("hyperalimentations"),_T("hypercoagulability"),_T("hyperconcentration"),_T("hyperconsciousness"),_T("hypercorrectnesses"),
_T("hyperimmunizations"),_T("hyperintellectuals"),_T("hypernationalistic"),_T("hyperpigmentations"),_T("hyperpolarizations"),_T("hyperrationalities"),_T("hypersensitiveness"),_T("hypersensitivities"),_T("hypersensitization"),_T("hypoparathyroidism"),
_T("hypophysectomizing"),_T("hyposensitizations"),_T("immeasurablenesses"),_T("immunocytochemical"),_T("immunodeficiencies"),_T("immunofluorescence"),_T("immunohematologies"),_T("immunohematologist"),_T("immunopathological"),_T("immunopathologists"),
_T("immunoprecipitated"),_T("immunoprecipitates"),_T("immunoreactivities"),_T("immunosuppressants"),_T("immunosuppressions"),_T("imperceptivenesses"),_T("imperishablenesses"),_T("impermissibilities"),_T("impersonalizations"),_T("imperturbabilities"),
_T("impracticabilities"),_T("inappreciativeness"),_T("inarticulatenesses"),_T("inauspiciousnesses"),_T("incombustibilities"),_T("incommensurability"),_T("incommodiousnesses"),_T("inconceivabilities"),_T("inconclusivenesses"),_T("inconsequentiality"),
_T("inconsiderableness"),_T("inconsolablenesses"),_T("incontestabilities"),_T("inconvertibilities"),_T("incorrigiblenesses"),_T("incorruptibilities"),_T("indefatigabilities"),_T("indestructibleness"),_T("indiscriminateness"),_T("indiscriminatingly"),
_T("indispensabilities"),_T("indisputablenesses"),_T("indissolublenesses"),_T("individualizations"),_T("industrializations"),_T("inexhaustibilities"),_T("inexplicablenesses"),_T("inexpressibilities"),_T("inexpressivenesses"),_T("inexpugnablenesses"),
_T("inharmoniousnesses"),_T("inhospitablenesses"),_T("institutionalising"),_T("institutionalizing"),_T("insubstantialities"),_T("insufferablenesses"),_T("insusceptibilities"),_T("intellectualnesses"),_T("intelligiblenesses"),_T("interchangeability"),
_T("intercolumniations"),_T("intercommunicating"),_T("intercommunication"),_T("interconnectedness"),_T("interinstitutional"),_T("intermediatenesses"),_T("interminablenesses"),_T("internationalising"),_T("internationalities"),_T("internationalizing"),
_T("interoperabilities"),_T("interpretabilities"),_T("interrelatednesses"),_T("interrelationships"),_T("intersubstitutable"),_T("intransitivenesses"),_T("intraventricularly"),_T("introspectionistic"),_T("invulnerablenesses"),_T("irreconcilableness"),
_T("irremediablenesses"),_T("irreplaceabilities"),_T("irrepressibilities"),_T("irreproachableness"),_T("irresistiblenesses"),_T("irresponsibilities"),_T("irresponsivenesses"),_T("irretrievabilities"),_T("knowledgeabilities"),_T("landlubberlinesses"),
_T("largeheartednesses"),_T("latitudinarianisms"),_T("lepidopterological"),_T("lepidopterologists"),_T("lightheartednesses"),_T("lipopolysaccharide"),_T("lymphangiographies"),_T("macroglobulinemias"),_T("macrophotographies"),_T("magnetoresistances"),
_T("magnetostrictively"),_T("maladministrations"),_T("malcontentednesses"),_T("manipulativenesses"),_T("mechanochemistries"),_T("melodramatizations"),_T("meretriciousnesses"),_T("metallographically"),_T("methemoglobinemias"),_T("methylcholanthrene"),
_T("methylnaphthalenes"),_T("methylprednisolone"),_T("microcalorimetries"),_T("microcrystallinity"),_T("microdensitometers"),_T("microdensitometric"),_T("microencapsulating"),_T("microencapsulation"),_T("microenvironmental"),_T("microlepidopterous"),
_T("micromanipulations"),_T("micrometeorologies"),_T("micrometeorologist"),_T("micromorphological"),_T("micropaleontologic"),_T("microphotographers"),_T("microphotographies"),_T("microphotographing"),_T("microradiographies"),_T("microreproductions"),
_T("mineralocorticoids"),_T("misadministrations"),_T("misclassifications"),_T("misidentifications"),_T("misinterpretations"),_T("misrepresentations"),_T("monochromaticities"),_T("mucopolysaccharide"),_T("muddleheadednesses"),_T("multicellularities"),
_T("multifariousnesses"),_T("myeloproliferative"),_T("neuroendocrinology"),_T("neuropharmacologic"),_T("neurophysiological"),_T("neurophysiologists"),_T("neuropsychiatrists"),_T("neuropsychological"),_T("neuropsychologists"),_T("neurotransmissions"),
_T("nonanthropological"),_T("nonanthropologists"),_T("nonarbitrarinesses"),_T("noncommutativities"),_T("noncomparabilities"),_T("nonconfrontational"),_T("noncontradictories"),_T("noncooperationists"),_T("nondeductibilities"),_T("nondestructiveness"),
_T("nondiscriminations"),_T("nonfraternizations"),_T("noninterchangeable"),_T("noninterventionist"),_T("nonrepresentatives"),_T("nonrevolutionaries"),_T("obstreperousnesses"),_T("ophthalmologically"),_T("opinionativenesses"),_T("organophosphoruses"),
_T("orthogonalizations"),_T("orthopsychiatrists"),_T("oscillographically"),_T("ostentatiousnesses"),_T("otherworldlinesses"),_T("overcapitalization"),_T("overcentralization"),_T("overclassification"),_T("overcommercialized"),_T("overcommercializes"),
_T("overcommunications"),_T("overconcentrations"),_T("overextrapolations"),_T("overfertilizations"),_T("overgeneralization"),_T("overidentification"),_T("overindebtednesses"),_T("overindustrialized"),_T("overindustrializes"),_T("overinterpretation"),
_T("overoptimistically"),_T("overprotectiveness"),_T("overrepresentation"),_T("oversimplification"),_T("overspecialization"),_T("paleoclimatologies"),_T("paleoclimatologist"),_T("particularizations"),_T("pathophysiological"),_T("pentachlorophenols"),
_T("pentylenetetrazols"),_T("perchloroethylenes"),_T("perpendicularities"),_T("pertinaciousnesses"),_T("phenomenologically"),_T("pheochromocytomata"),_T("phonocardiographic"),_T("phosphodiesterases"),_T("phosphoglucomutase"),_T("photodecomposition"),
_T("photodisintegrated"),_T("photodisintegrates"),_T("photodissociations"),_T("photolithographies"),_T("photolithographing"),_T("photomicrographies"),_T("photomorphogeneses"),_T("photomorphogenesis"),_T("photoreactivations"),_T("photoreproductions"),
_T("photosensitivities"),_T("photosensitization"),_T("photosynthetically"),_T("physiopathological"),_T("phytohemagglutinin"),_T("piezoelectricities"),_T("polyacrylonitriles"),_T("polychromatophilia"),_T("polychromatophilic"),_T("polyesterification"),
_T("polymorphonuclears"),_T("polyribonucleotide"),_T("postmillenarianism"),_T("postmillennialisms"),_T("postmillennialists"),_T("postpsychoanalytic"),_T("praiseworthinesses"),_T("predestinarianisms"),_T("premillenarianisms"),_T("preposterousnesses"),
_T("presumptuousnesses"),_T("proletarianization"),_T("pronounceabilities"),_T("propagandistically"),_T("propertylessnesses"),_T("provincializations"),_T("pseudonymousnesses"),_T("pseudotuberculoses"),_T("pseudotuberculosis"),_T("psychoanalytically"),
_T("psychobiographical"),_T("psychopathological"),_T("psychopathologists"),_T("psychopharmacology"),_T("psychophysiologies"),_T("psychophysiologist"),_T("puzzleheadednesses"),_T("quantificationally"),_T("quantitativenesses"),_T("quasiperiodicities"),
_T("quattuordecillions"),_T("questionablenesses"),_T("radiochromatograms"),_T("radiosensitivities"),_T("rambunctiousnesses"),_T("rechromatographies"),_T("rechromatographing"),_T("reconstructionisms"),_T("reconstructionists"),_T("recrystallizations"),
_T("redistributionists"),_T("rehospitalizations"),_T("remunerativenesses"),_T("renationalizations"),_T("reprehensibilities"),_T("representationally"),_T("representativeness"),_T("representativities"),_T("revascularizations"),_T("rhabdomyosarcomata"),
_T("ribonucleoproteins"),_T("roentgenologically"),_T("sacrilegiousnesses"),_T("satisfactorinesses"),_T("sedimentologically"),_T("semiconservatively"),_T("semidomestications"),_T("semipermeabilities"),_T("semiprofessionally"),_T("semiquantitatively"),
_T("sentimentalization"),_T("shortsightednesses"),_T("simplemindednesses"),_T("simultaneousnesses"),_T("sociopsychological"),_T("somnambulistically"),_T("soporiferousnesses"),_T("spectrofluorimeter"),_T("spectrofluorometer"),_T("spectrofluorometry"),
_T("spectrographically"),_T("spectroheliographs"),_T("spectroheliography"),_T("spectrohelioscopes"),_T("spectrophotometers"),_T("spectrophotometric"),_T("sphygmomanometries"),_T("stereophotographic"),_T("stereoregularities"),_T("stereospecifically"),
_T("stoichiometrically"),_T("stoutheartednesses"),_T("structuralizations"),_T("subcategorizations"),_T("subclassifications"),_T("subconsciousnesses"),_T("submicroscopically"),_T("substitutabilities"),_T("superadministrator"),_T("superciliousnesses"),
_T("supercivilizations"),_T("superconglomerates"),_T("superintellectuals"),_T("superintelligences"),_T("superminicomputers"),_T("supernaturalnesses"),_T("supersensitivities"),_T("supersophisticated"),_T("supranationalities"),_T("tachistoscopically"),
_T("telecommunications"),_T("territorialization"),_T("theatricalizations"),_T("thermoluminescence"),_T("thermoplasticities"),_T("thrombophlebitides"),_T("thrombophlebitises"),_T("transcendentalisms"),_T("transcendentalists"),_T("transformationally"),
_T("transilluminations"),_T("transistorizations"),_T("transmissibilities"),_T("transmogrification"),_T("transportabilities"),_T("transubstantiating"),_T("transubstantiation"),_T("triboelectricities"),_T("triboluminescences"),_T("trichloroethylenes"),
_T("triskaidekaphobias"),_T("ultracentrifugally"),_T("ultraconservatisms"),_T("ultraconservatives"),_T("ultramicroscopical"),_T("ultranationalistic"),_T("ultrarevolutionary"),_T("ultrasophisticated"),_T("unaccountabilities"),_T("unassailablenesses"),
_T("unattractivenesses"),_T("unchangeablenesses"),_T("uncharitablenesses"),_T("uncompromisingness"),_T("unconscionableness"),_T("unconstitutionally"),_T("unconvincingnesses"),_T("unenthusiastically"),_T("ungrammaticalities"),_T("uniformitarianisms"),
_T("unintelligibleness"),_T("unpredictabilities"),_T("unprinciplednesses"),_T("unprofitablenesses"),_T("unreasonablenesses"),_T("unresponsivenesses"),_T("unrestrainednesses"),_T("unsatisfactoriness"),_T("unscrupulousnesses"),_T("unseasonablenesses"),
_T("unsubstantialities"),_T("vaingloriousnesses"),_T("valetudinarianisms"),_T("verisimilitudinous"),_T("videoconferencings"),_T("weatherproofnesses"),
0};
